translate.misc.ini.CommentLine

Package translate :: Package misc :: Module ini :: Class CommentLine |
[hide private]
[frames] | no frames]

# Class CommentLine

source code

Instance Methods | [hide private]
__init__(self, comment=`'````'`, separator=`'``#``'`, line=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
to_string(self) | source code
Inherited from `LineType`: `__setattr__`, `__str__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`

Class Methods | [hide private]
parse(cls, line) | source code

Class Variables | [hide private]
| regex = `re.compile(r'^`(?P<``csep``>``[`;#`]``|``[`rR`]``[`eE`]``[`mM`]``)``(?P<``comment``>`.`...``
Inherited from `LineType`: `line`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, comment=`'````'`, separator=`'``#``'`, line=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### to_string(self) | source code
Overrides: LineType.to_string

Class Variable Details | [hide private]

  ### regex Value:
      re.compile(r'^(?P<csep>[;#]|[rR][eE][mM])(?P<comment>.*)$')